@@ -3,13 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw Guitar Chord Diagrams
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
 use namespace::clean;
 
 use Imager;
+use List::MoreUtils 'first_index';
 use Music::Chord::Namer 'chordname';
 
 
@@ -60,16 +61,13 @@ has font => (
 
 has notes => (
     is      => 'ro',
-    default => sub {
-        {
-            1 => [qw/E F  Gb G  Ab A Bb B  C  Db D Eb/],
-            2 => [qw/B C  Db D  Eb E F  Gb G  Ab A Bb/],
-            3 => [qw/G Ab A  Bb B  C Db D  Eb E  F Gb/],
-            4 => [qw/D Eb E  F  Gb G Ab A  Bb B  C Db/],
-            5 => [qw/A Bb B  C  Db D Eb E  F  Gb G Ab/],
-            6 => [qw/E F  Gb G  Ab A Bb B  C  Db D Eb/],
-        }
-    },
+    default => sub { [qw/E B G D A E/] },
+);
+
+
+has fretboard => (
+    is       => 'rw',
+    init_arg => undef,
 );
 
 
@@ -79,6 +77,24 @@ has verbose => (
 );
 
 
+sub BUILD {
+    my ( $self, $args ) = @_;
+
+    my @scale = qw/C Db D Eb E F Gb G Ab A Bb B/;
+    my @index = map { my $t = $_; first_index { $t eq $_ } @scale } @{ $self->notes };
+    my %notes;
+
+    my $n = 0;
+
+    for my $i ( @index ) {
+        $n++;
+        $notes{$n} = [ map { $scale[ ($i + $_) % @scale ] } 0 .. @scale - 1 ];
+    }
+
+    $self->fretboard(\%notes);
+}
+
+
 sub draw {
     my ($self) = @_;
 
@@ -154,7 +170,7 @@ sub draw {
             );
         }
         elsif ( $note =~ /[oO0]/ ) {
-            my $temp = $self->notes->{$string}[0];
+            my $temp = $self->fretboard->{$string}[0];
             push @chord, $temp;
             print "O at 0,$string = $temp\n" if $self->verbose;
 
@@ -169,7 +185,7 @@ sub draw {
             );
         }
         else {
-            my $temp = $self->notes->{$string}[$self->position + $note - 1];
+            my $temp = $self->fretboard->{$string}[$self->position + $note - 1];
             push @chord, $temp;
             print "Dot at $note,$string = $temp\n" if $self->verbose;
 
@@ -217,7 +233,7 @@ Music::GuitarChordDiagram - Draw Guitar Chord Diagrams
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -231,7 +247,7 @@ version 0.0200
     size       => 30,
     outfile    => 'chord-diagram',
     font       => '/path/to/TTF/font.ttf',
-    notes      => { 1 => [qw/D Eb E F .../], 2 => [qw/.../], },
+    notes      => [qw/E B G D A E/],
     verbose    => 1,
   );
 
@@ -264,7 +280,7 @@ Examples:
   f: xx3211
   g: 210002
   a: x02220
-  b: xx4442
+  b: x24442
  
   cm: xx5543
   dm: xx0231
@@ -272,7 +288,7 @@ Examples:
   fm: xx3111
   gm: xx5333
   am: x02210
-  bm: xx4432
+  bm: x24432
  
   c7: x32310
   d7: xx0212
@@ -335,16 +351,16 @@ Default: /opt/X11/share/fonts/TTF/VeraMono.ttf
 
   $notes = $dia->notes;
 
-A hashref of string keys and note list values to use in computing the chord.
+An arrayref of the string tuning.  The order of the notes is from highest string
+(1st) to lowest (6th).
 
-Default:
+Default: [ E B G D A E ]
 
-  1 => [ E F  Gb G  Ab A Bb B  C  Db D Eb ]
-  2 => [ B C  Db D  Eb E F  Gb G  Ab A Bb ]
-  3 => [ G Ab A  Bb B  C Db D  Eb E  F Gb ]
-  4 => [ D Eb E  F  Gb G Ab A  Bb B  C Db ]
-  5 => [ A Bb B  C  Db D Eb E  F  Gb G Ab ]
-  6 => [ E F  Gb G  Ab A Bb B  C  Db D Eb ]
+=head2 fretboard
+
+  $fretboard = $dia->fretboard;
+
+A hashref of the string notes.  This is a computed attribute.
 
 =head2 verbose
 
@@ -362,6 +378,10 @@ Default: 0
 
 Create a new C<Music::GuitarChordDiagram> object.
 
+=head2 BUILD
+
+Construct the B<fretboard> attribute from the B<notes>.
+
 =head2 draw()
 
   $dia->draw;
@@ -372,6 +392,8 @@ Render the requested chord diagram as a PNG image.
 
 L<Imager>
 
+L<List::MoreUtils>
+
 L<Moo>
 
 L<Music::Chord::Namer>
